#!/bin/sh

############################################################################
#
#  Source Name :  set_net_lin.sh
#  Option      :  none        -> Same as -src . -dst NX.
#                 -src [path] -> Path the network connection files
#                                to be copied are stored.
#                 -dst [type] -> NX :Files will be added to the data folder
#                                    of ColorNavigator NX.
#                                Net:Files will be added to the data folder
#                                    of NetAgent.
#  Result Code : 0    -> No errors occurred. Proxy.xml was copied.
#                1    -> No errors occurred. Proxy.xml was created.
#                2    -> Connection.xml not found.
#                128  -> Invalid argument.
#
############################################################################

# 変数定義
CURRENT_PATH=
OUT_FILE_PATH=
NX_PATH='/var/opt/EIZO/ColorNavigator NX/'
NET_PATH='/var/opt/EIZO/ColorNavigator NetAgent/'
CONNECTION_NAME=Connection.xml
PROXY_NAME=Proxy.xml
HTTPS_NM=HTTPS_
PARAM_ERROR=0
CHECK_COUNT_SRC=0
CHECK_COUNT_DST=0

# 初期値設定
OUT_FILE_PATH="${NX_PATH}"

# 引数確認
while [ $# -ge 1 ]; do
    case "$1" in
        -src)
            shift
            if [ -z "$1" ]; then
                PARAM_ERROR=1
            elif [ "${1: -1}" = '/' ]; then
                CURRENT_PATH="$1"
            else
                CURRENT_PATH="$1/"
            fi
            CHECK_COUNT_SRC=`expr ${CHECK_COUNT_SRC} + 1`
            if [ "${CHECK_COUNT_SRC}" -ge 2 ]; then
                PARAM_ERROR=1
            fi
            ;;
        -dst)
            shift
            DST_VALUE=`echo "$1" | tr "a-z" "A-Z"`
            if [ "${DST_VALUE}" = 'NX' ]; then
                OUT_FILE_PATH="${NX_PATH}"
            elif [ "${DST_VALUE}" = 'NET' ]; then
                OUT_FILE_PATH="${NET_PATH}"
            else
                PARAM_ERROR=1
            fi
            CHECK_COUNT_DST=`expr ${CHECK_COUNT_DST} + 1`
            if [ "${CHECK_COUNT_DST}" -ge 2 ]; then
                PARAM_ERROR=1
            fi
            ;;
        *)
            PARAM_ERROR=1
            break
            ;;
    esac
    shift
done

# パラメータ不正の場合、終了
if [ "${PARAM_ERROR}" -eq 1 ]; then
    exit 128
fi

# Connection.xmlファイルパス作成
FILE_PATH="${CURRENT_PATH}${CONNECTION_NAME}"

# Connection.xmlファイルが存在しない場合、終了
if [ ! -e "${FILE_PATH}" ]; then
    exit 2
fi

if [ ! -d "${OUT_FILE_PATH}" ]; then
    mkdir -p "${OUT_FILE_PATH}"
    chmod 777 -R "${OUT_FILE_PATH}"
fi

# Connection.xmlファイルコピー
cp -p "${FILE_PATH}" "${OUT_FILE_PATH}${CONNECTION_NAME}"
chmod 666 "${OUT_FILE_PATH}${CONNECTION_NAME}"

# Proxy.xmlファイルパス作成
FILE_PATH="${CURRENT_PATH}${PROXY_NAME}"
# Proxy.xmlファイル出力パス作成
OUT_FILE_NAME="${OUT_FILE_PATH}${PROXY_NAME}"

# Proxy.xmlファイルが存在する場合、ファイルコピーを行い、終了
if [ -e "${FILE_PATH}" ]; then
    cp -p "${FILE_PATH}" "${OUT_FILE_NAME}"
    chmod 666 "${OUT_FILE_NAME}"
    exit 0
fi


# 環境変数より取得
PROXY_VALUE=
PORT_VALUE=
for i in `env | grep -i ${HTTPS_NM} | sort -u | cut -d= -f2 | sed -e "s/[^\/]*:\/\///"`
do
    if [ ! -e $i ]; then
        PROXY_VALUE=`echo $i | cut -d: -f1`
        PORT_VALUE=`echo $i | cut -s -d: -f2`
        break
    fi
done

if [ ! -e ${PORT_VALUE} ] && [ ${PORT_VALUE} = 0 ] ; then
    PORT_VALUE=
else
    PORT_VALUE=${PORT_VALUE//[!0-9]/}
fi

# ファイル作成
echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" > "${OUT_FILE_NAME}"
echo "<Proxy Version=\"1\">" >> "${OUT_FILE_NAME}"
if [ -e ${PROXY_VALUE} ]; then
    # 値未設定の場合、タグのみ
    echo "  <Host/>" >> "${OUT_FILE_NAME}"
else
    echo "  <Host>${PROXY_VALUE}</Host>" >> "${OUT_FILE_NAME}"
fi
if [ -e ${PORT_VALUE} ]; then
    # 値未設定の場合、タグのみ
    echo "  <Port/>" >> "${OUT_FILE_NAME}"
else
    echo "  <Port>${PORT_VALUE}</Port>" >> "${OUT_FILE_NAME}"
fi
echo "</Proxy>" >> "${OUT_FILE_NAME}"
chmod 666 "${OUT_FILE_NAME}"

exit 1

